@@ -30,7 +30,7 @@ def main():
         log.exception(f"{FileNotFoundError} {e}")
         os.startfile(os.path.join(os.getcwd(), "project parameters.yaml"))
     try:
-        _run(*decomporess(data_loaded))
+        _run(*decompress(data_loaded))
     except TypeError as e:
         raise e
         print("Please double-check your project parameters.yaml document'")
@@ -38,11 +38,11 @@ def main():
         os.startfile(os.path.join(os.getcwd(), "project parameters.yaml"))
 
 
-def decomporess(data_loaded):
+def decompress(data_loaded):
     wavelenths = data_loaded.get("WAVE LENGTHS")
-    gradient = data_loaded.get("GRADIENT")
+    gradient = data_loaded.get("GRADIENTS")
     # rms = data_loaded.get("RMS") #TODO: Support RMS
-    root = data_loaded.get("PROJECT DIRECTORY")
+    root = data_loaded.get("DIRECTORY")
     isotherms = data_loaded.get("ISOTHERMS")
     baselines = data_loaded.get("BASELINE DIRECTORY")
 
