@@ -7,7 +7,7 @@ from collections import defaultdict
 def write_yaml():
     return {
         "BASELINE DIRECTORY": "",
-        "PROJECT DIRECTORY": "",
+        "DIRECTORY": "",
         "WAVE LENGTHS": [None, None, None, None],
         "GRADIENTS": [10],
         # "RMS": False, TODO: Support RMS
